@@ -4,12 +4,21 @@ vuniroot <-
               f.lower = f(lower, ...), f.upper = f(upper, ...),
               extendInt = c("no", "yes", "downX", "upX"),
               check.conv = FALSE, tol = .Machine$double.eps^0.25,
-              maxiter = 1000, trace = 0)
+              maxiter = 1000, trace = 0, n=NULL)
 {
     if (!missing(interval) && ncol(interval) != 2L)
         stop("'interval' must be a matrix with two columns")
     if (all(!is.numeric(lower) | !is.numeric(upper) | lower >= upper))
         stop("lower < upper  is not fulfilled")
+    if (is.null(n) && length(lower) == 1 && length(upper) == 1 && length(f.lower) > 1)
+        n <- length(f.lower)
+    ## warning("Bounds have length 1: possibly replicate for the bounds to have the correct length")
+    if (!is.null(n) && length(lower) == 1 && length(upper) == 1) {
+        lower = rep(lower,n)
+        upper = rep(upper,n)
+        f.lower = f(lower, ...)
+        f.upper = f(upper, ...)
+    }
     if (any(is.na(f.lower)))
         stop("f.lower = f(lower) is NA at least once")
     if (any(is.na(f.upper)))
