@@ -189,11 +189,10 @@ test_that("Predictions with missing values - stpm2+frailty", {
 
 ## pstpm2
 context("Missing data - pstpm2")
-beta3 <- c(-1.47525690836724, -0.363074536498542, 0.0297855655113729, 
-           -0.00100996506126849, -0.0685624850620158, -0.0798332090346169, 
-           -0.02739042575511, 0.0823846831092255, -0.0604689585097724, 0.736732107640801, 
-           1.17246469142944)
-
+beta3 <- c(-1.47525883324765, -0.363074906965698, -0.0297899626776523, 
+           -0.00101016513169846, 0.0685630331474268, -0.0798313222245555, 
+           -0.027390133765054, 0.0823829591366898, -0.060469244786851, 0.73673273581378, 
+           1.17246776262782)
 test_that("Missing event time - pstpm2", {
     brcancer2 <- rstpm2::brcancer
     ##
